@@ -3,15 +3,16 @@ package Class::Mock::Method::InterfaceTester;
 use strict;
 use warnings;
 
-our $VERSION = '1.3000';
+our $VERSION = '1.3001';
 
 # all this pre-amble is damned near identical to C::M::G::IT. Re-factor.
 use Test::More ();
 use Data::Compare;
 use Scalar::Util qw(blessed);
 use PadWalker qw(closed_over);
-use Data::Dumper;
-local $Data::Dumper::Indent = 1;
+use Data::Dumper::Concise;
+
+use Class::Mock::Common ();
 
 use Class::Mockable
     _ok => sub { Test::More::ok($_[0], @_[1..$#_]) };
@@ -34,7 +35,12 @@ use constant {
 sub new {
     my $class = shift;
     my $called_from = (caller(1))[3];
-    my @tests = @{shift()};
+
+    my $tests = shift;
+    my @tests;
+    if(ref($tests) eq 'ARRAY') { @tests = @{$tests}; }
+     else { @tests = Class::Mock::Common::_get_tests_from_file(${$tests});
+    }
 
     return bless(sub {
         if(!@tests) { # no tests left
@@ -184,6 +190,56 @@ the right class (again, not a subclass), or 'invocant_object' subref to
 check that it's being called on an object that, when passed to the sub-ref,
 returns true.
 
+Alternatively, C<new> can read fixture data from a file.
+
+Recording fixtures to a file is not yet implemented.
+
+=cut
+
+# or you can use it
+# to pass args through to other code and record its responses to a file.
+
+=over
+
+=item reading from a file
+
+Pass a reference to a scalar as the first argument. Any subsequent arguments
+will be ignored:
+
+    Class::Mock::Method::InterfaceTester->new(\"filename.dd");
+
+Yes, that's a reference to a scalar. The scalar is assumed to be a filename
+which will be read, and whose contents should be valid arguments to create
+fixtures.
+
+=cut
+
+# =item recording and writing to a file
+# 
+# Set the environment varilable PERL_CMMIT_RECORD to a true value and Pass a
+# reference to a scalar as the first argument, following by the name of class
+# whose interactions you want to record, and optionally either a list of method
+# names or a regular expression matching some method names:
+# 
+#     Class::Mock::Method::InterfaceTester->new(
+#         \"filename.dd",
+#         'I::Want::To::Mock::This',
+#         qw(but only these methods) # or qr/^(but|only|these|methods)$/
+#     );
+# 
+# In the absence of a list of methods (or a regex) then all methods will be
+# recorded, including those inherited from superclasses, except those whose names
+# begin with an underscore.
+
+=back
+
+=cut
+
+# The observant amongst you will have noticed that because when reading from
+# a file all arguments after the first are ignored, then you can choose to
+# record or to playback by just setting the environment variable and making
+# no other changes. This is deliberate.
+
 =head1 SEE ALSO
 
 L<Class::Mockable>
